# efts-io

[![ci](https://github.com/csiro-hydroinformatics/efts-io/workflows/ci/badge.svg)](https://github.com/csiro-hydroinformatics/efts-io/actions?query=workflow%3Aci)
[![documentation](https://img.shields.io/badge/docs-mkdocs-708FCC.svg?style=flat)](https://csiro-hydroinformatics.github.io/efts-io/)
[![pypi version](https://img.shields.io/pypi/v/efts-io.svg)](https://pypi.org/project/efts-io/)
[![gitpod](https://img.shields.io/badge/gitpod-workspace-708FCC.svg?style=flat)](https://gitpod.io/#https://github.com/csiro-hydroinformatics/efts-io)
[![gitter](https://badges.gitter.im/join%20chat.svg)](https://app.gitter.im/#/room/#efts-io:gitter.im)

Ensemble forecast time series

## Installation

**Placeholder**, the package is under development. See [contributing.md](./contributing.md) for contributing or installing as a developer.

<!-- With `pip`:

```bash
pip install efts-io
```

With [`pipx`](https://github.com/pipxproject/pipx):

```bash
python -m pip install --user pipx
pipx install efts-io
``` -->

## Development workflow

Quick link to [copier-uv: Working on a project](https://pawamoy.github.io/copier-uv/work), but see [contributing.md](./contributing.md) for details.
